#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_RROL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_RROL_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/rrol.hpp>

#endif
